Endpoint

Struct Endpoint 

pub struct Endpoint {
Show 23 fields pub id: String, pub user_id: Option<String>, pub name: Option<String>, pub version: Option<i32>, pub compute_type: Option<String>, pub workers_min: Option<i32>, pub workers_max: Option<i32>, pub flashboot: Option<bool>, pub idle_timeout: Option<i32>, pub execution_timeout_ms: Option<i32>, pub scaler_type: Option<String>, pub scaler_value: Option<i32>, pub gpu_count: Option<i32>, pub gpu_type_ids: Option<Vec<String>>, pub allowed_cuda_versions: Option<Vec<String>>, pub instance_ids: Option<Vec<String>>, pub network_volume_id: Option<String>, pub data_center_ids: Option<Vec<String>>, pub env: Option<HashMap<String, String>>, pub template_id: Option<String>, pub template: Option<Template>, pub created_at: Option<String>, pub workers: Option<Vec<Pod>>,
}

Fields

id: String

Unique ID of the endpoint

user_id: Option<String>

The user who created the endpoint

name: Option<String>

A user-defined name for a Serverless endpoint

version: Option<i32>

The latest version of a Serverless endpoint (updated whenever the template or env vars change)

compute_type: Option<String>

The compute type: “CPU” or “GPU”

workers_min: Option<i32>

The minimum number of Workers that will always be running

workers_max: Option<i32>

The maximum number of Workers that can be running at the same time

flashboot: Option<bool>

If true, flash boot is used

idle_timeout: Option<i32>

The number of seconds a Worker can run without taking a job before being scaled down

execution_timeout_ms: Option<i32>

The maximum number of ms for an individual request before the Worker is stopped

scaler_type: Option<String>

The method used to scale up Workers: “QUEUE_DELAY” or “REQUEST_COUNT”

scaler_value: Option<i32>

If scalerType=QUEUE_DELAY, number of seconds before scaling; if REQUEST_COUNT, a divisor for the queue

gpu_count: Option<i32>

Number of GPUs attached to each Worker

gpu_type_ids: Option<Vec<String>>

An ordered list of acceptable GPU types (strings)

allowed_cuda_versions: Option<Vec<String>>

A list of acceptable CUDA versions for GPU endpoints

instance_ids: Option<Vec<String>>

For CPU endpoints only; a list of CPU instance IDs

network_volume_id: Option<String>

Unique ID of an attached network volume

data_center_ids: Option<Vec<String>>

A list of RunPod data center IDs where Workers can be located

env: Option<HashMap<String, String>>

Environment variables for the endpoint

template_id: Option<String>

ID of the template used to create this endpoint

template: Option<Template>

Information about the template (if included in the response)

created_at: Option<String>

The UTC timestamp when a Serverless endpoint was created

workers: Option<Vec<Pod>>

Information about the current Workers (if included in the response)